﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2012 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Collections.Generic;
using HeuristicLab.Data;

namespace HeuristicLab.Analysis.AlgorithmBehavior {
  public class SchemaEqualityComparer : EqualityComparer<IntArray> {
    public override bool Equals(IntArray x, IntArray y) {
      if (object.ReferenceEquals(x, y)) return true;
      if (x == null || y == null || x.Length != y.Length) return false;
      bool match = true;
      for (int i = 0; i < x.Length && match; i++) // check normal tour
        if (x[i] != y[i]) match = false;
      if (!match) {
        match = true;
        for (int i = x.Length - 1; i >= 0 && match; i--) // check inverse tour
          if (x[i] != y[i]) match = false;
      }
      return match;
    }

    public override int GetHashCode(IntArray obj) {
      return 0; // return the same hash code for each object, otherwise Equals will not be called
    }
  }
}
